/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWRUNTIME_UTILS_NAMESPACE_HPP__
#define __FWRUNTIME_UTILS_NAMESPACE_HPP__

namespace fwRuntime
{
/**
 * @brief       The namespace fwRuntime::utils contains template executable factory classes
 * @namespace   fwRuntime::utils
 *
 * @date        2009-2010.
 *
 */
namespace utils
{

}
}
#endif /* __FWRUNTIME_UTILS_NAMESPACE_HPP__ */
